Detailed description of functions and arguments (API)
=====================================================

.. currentmodule:: naima

.. toctree::
    :maxdepth: 1

    api-mcmc.rst
    api-models.rst
    api-convenience.rst
